.. all-saltext.namecheap.modules:

_________________
Execution Modules
_________________

.. currentmodule:: saltext.namecheap.modules

.. autosummary::
    :toctree:

    namecheap_domains
    namecheap_domains_dns
    namecheap_domains_ns
    namecheap_ssl
    namecheap_users
